#delimit;
clear;
set more off;
estimates clear;


*/----------------------------------------------------------------
	Replicate Tables 1 to 5 and appendix material from:
	
		Bidwell, Casey and Glennerster, "Debates" 
		
	NOTE: Running this file requires installation of user written command "estout"
	
	This do file uses the following de-identified datasets:
	- deb_vrc_exit
	- deb_ind_exit
	- deb_nec_vrc
	- deb_vrc_implem
	- deb_comm_exit
	- deb_experts
	- deb_parl_records
	- deb_field_audits
	
	And generates the following outputs for tables, figures and appendix material:
	- Table 1: tab1_cols1_2_5, tab1_col4
	- Table 2: tab2, tab2_nec
	- Table 3: tab3, tab3_alt1, tab3_alt2, tab3_panC_apc, tab3_panC_slpp, tab3_panC_pmdc
	- Table 4: tab4_mei, tab4_ios
	- Table 5: tab5a_rows123, tab5a_rows45, tab5b_priv, tab5b_public
	- Appendix C: appC_panA
	- Appendix D: appD
	- Appendix G: appG
	- Appendix H: appH, appH_panC_apc, appH_panC_slpp, appH_panC_pmdc
	- Appendix I: appI_mei, appI_ios
	- Appendix J: appJ
	- Appendix K: appK_a, appK_b
	- Appendix L: appL
	- Appendix M: appM_mei, appM_ios
	- Appendix N: appN_priming, appN_reinforcing
	
	Note that output for Appendix A and some of Appendix C are omitted as the content identifies individual MPs

	last modified by Kate 14 August 2019
------------------------------------------------------------------/;

cd;
set seed 500;

***********************************************;
***  1. CODE UP DEBATE WINNERS   ***;
***********************************************;

* A. Audience pick: from VRC implementation data, drop host VRC of interest when defining; 

use "deb_vrc_implem.dta", clear;
	keep if after==1;
	keep constit vrc after attended cand_best;
	drop if cand_best==.;
	gen apc_best=.;
	replace apc_best=1 if cand_best==1;
	gen slpp_best=.;
	replace slpp_best=1 if cand_best==2;
	gen pmdc_best=.;
	replace pmdc_best=1 if cand_best==3;
	* for i-level and controls, const-wide already omits VRC of interest;
	bys const: egen tot_slpp=total(slpp_best);
	bys const: egen tot_apc=total(apc_best);
	bys const: egen tot_pmdc=total(pmdc_best);
	egen max=rowmax(tot_slpp tot_apc tot_pmdc);
	gen conbest=1 if tot_apc==max;
	replace conbest=2 if tot_slpp==max;
	replace conbest=3 if tot_pmdc==max;
	label define parties 1 "APC" 2 "SLPP" 3 "PMDC";
	label values conbest parties;
	
	keep constit vrc apc_best slpp_best pmdc_best conbest;
	gen apc_best2=apc_best;
	gen slpp_best2=slpp_best;
	gen pmdc_best2=pmdc_best;
	gen vrcbest=.;
save "temp_vrc_best.dta", replace;

local vrc_masked 375528 807744 643554 126273 570850 634186 939842 816595 311867 472969 506759 163815 196503 751823 971429
	946564 193278 719217 552378 683575 860395 462473 120950 170443 642671 647055 581496 272089 101170 850057 220053 341579
	874105 758072 529460 599168 273490 825070 202674 429402 845400 136250 889533 497019 284279 303562 543254 663501 712678
	463828 414499 180210 846367 328162 647074 459455 704280 575678 528850 727425 346205 964177 535998 722000 784796 627365
	904719 360882 306668 965473 583893 160850 936047 604654 392222 832952 448639 723637 104977 519486 825739 453144 856631
	939151 214643 568484 848318 954180 441599 239411 986138 604639 976174 702244 562695 688515 116395 434023 499206 220394
	867430 758621 345252 816979 726892 305788 196872 783083 203445 294317 541349;

foreach x in `vrc_masked' {;
	use "temp_vrc_best.dta", clear;
		foreach var in slpp_best apc_best pmdc_best{;
				replace `var'=. if vrc==`x';
				};
		bys const: egen vtot_slpp=total(slpp_best);
		bys const: egen vtot_apc=total(apc_best);
		bys const: egen vtot_pmdc=total(pmdc_best);
		egen vmax=rowmax(vtot_slpp vtot_apc vtot_pmdc);
		replace vrcbest=1 if vtot_apc==vmax & vrc==`x';
		replace vrcbest=2 if vtot_slpp==vmax & vrc==`x';
		replace vrcbest=3 if vtot_pmdc==vmax & vrc==`x';
		drop vtot_slpp vtot_apc vtot_pmdc vmax;
		foreach var in slpp_best apc_best pmdc_best{;
				replace `var'=`var'2 if vrc==`x';
				};
		save "temp_vrc_best.dta", replace;
		};
use "temp_vrc_best.dta", clear;
	collapse const conbest vrcbest, by(vrc);
	label values vrcbest parties;
save "temp_vrc_best.dta", replace;
	collapse conbest, by(const);
	label values conbest parties;
save "temp_con_best.dta", replace;
use "temp_vrc_best.dta", clear;
	drop conbest;
save "temp_vrc_best.dta", replace;

* B. Expert pick: use average across all experts, all questions, multiply C Qs by 5 since A Qs are on 1 to 10 scale;
use "deb_experts.dta", clear;
	foreach var in c8apc c8slpp c8pmdc{;
		replace `var'=-1*`var';
	};
	
	foreach x in apc slpp pmdc{;
		egen tot_a_`x'=rowtotal(a1`x' a2`x' a3`x' a4`x' a5`x' a6`x' a7`x' a8`x' a9`x' a10`x'), missing;
		egen tot_c_`x'=rowtotal(c1`x' c2`x' c3`x' c4`x' c5`x' c6`x' c7`x' c8`x' c9`x' c10`x' c11`x' c12`x' c13`x' c14`x' c15`x' c16`x' c17`x' c18`x' c19`x'), missing;
		replace tot_c_`x'=tot_c_`x' + 1;
		gen sum_`x'=tot_a_`x'+5*tot_c_`x';
	};
	* correct scores for tot_c and sum where a cand received no C votes (i.e. all missing that should properly be counted as zero);
	replace tot_c_slpp=1 if uniqueid=="212G";
	replace sum_slpp=tot_a_slpp + tot_c_slpp if uniqueid=="212G";
	replace tot_c_pmdc=1 if uniq=="112B" | uniq=="212D" | uniq=="123A";
	replace sum_pmdc=tot_a_pmdc + tot_c_pmdc if uniq=="112B" | uniq=="212D" | uniq=="123A";
	collapse sum_apc sum_slpp sum_pmdc, by(const);
	egen exp_max=rowmax(sum_apc sum_slpp sum_pmdc);
	gen exp_best=.;
	replace exp_best=1 if sum_apc==exp_max;
	replace exp_best=2 if sum_slpp==exp_max;
	replace exp_best=3 if sum_pmdc==exp_max;
	keep constit exp_best;
save "temp_exp_best.dta", replace;


***********************************************;
*** 2. FORMAT VOTER OUTCOMES  ***;
***********************************************;
use "deb_vrc_exit.dta", clear;
save "deb_vrc_analysis.dta", replace;

use "deb_ind_exit.dta", clear;
save "deb_ind_analysis.dta", replace;

foreach file in "deb_vrc_analysis.dta" "deb_ind_analysis.dta"{;
	use "`file'", clear;

*** Respondent characteristics;
	gen polyg=0 if marriage<.;
	replace polyg=1 if marriage==5;
	gen farmer=0 if occup<81;
	replace farmer=1 if inlist(occup, 1, 2);
	gen apc_2007=0 if party_2007<.;
	replace apc_2007=1 if party_2007==1;
	gen eloyal_apc=0 if inlist(ethnicity, 2, 8, 6);
	replace eloyal_apc=1 if inlist(ethnicity, 1, 5, 14, 13, 3, 7);

*** H1. Political Knowledge outcomes;

	egen roles=anycount(mp_roles1 mp_roles2 mp_roles3 mp_roles4), values(1 2 3);
	replace roles=. if mp_roles=="";

	gen cff_close=0 if cff!=.;
	* recall .c is don't know;
	replace cff_close=1 if inrange(cff, 40, 50);
	* these below are likely enumerator errors;
	replace cff_close=1 if inrange(cff, 4000000, 5000000);
	replace cff_close=1 if inrange(cff, 40000000, 50000000);
	replace cff_close=1 if cff==43800;

	gen fhc_correct=0 if fhc<.;
	replace fhc_correct=1 if fhc==1;

	gen geb_correct=0 if geb<.;
	replace geb_correct=1 if geb==2;

	*** Candidate issue positions are recorded in "deb_cand_positions.dta";
	gen iss_slpp=0 if issues_slpp<.;
	replace iss_slpp=1 if issues_slpp==2 & inlist(constit, 6398, 7202, 1706, 2156);
	replace iss_slpp=1 if issues_slpp==3 & inlist(constit, 8553, 4575, 8614, 8617);
	replace iss_slpp=1 if issues_slpp==1 & inlist(constit, 4800, 6051, 7777);
	replace iss_slpp=1 if inlist(issues_slpp, 5, 7) & inlist(constit, 3640, 2843);
	replace iss_slpp=1 if issues_slpp==4 & inlist(constit, 2056);

	gen iss_apc=0 if issues_apc<.;
	replace iss_apc=1 if issues_apc==3 & inlist(constit, 8553, 3640, 7777, 8617);
	replace iss_apc=1 if issues_apc==2 & inlist(constit, 7202, 2843, 4575);
	replace iss_apc=1 if issues_apc==4 & inlist(constit, 4800, 8614, 1706, 2156, 2056);
	replace iss_apc=1 if issues_apc==1 & inlist(constit, 6051);

	gen iss_pmdc=0 if issues_pmdc<.;
	replace iss_pmdc=1 if issues_pmdc==2 & inlist(constit, 6398, 2843, 7777, 2056);
	replace iss_pmdc=1 if issues_pmdc==3 & inlist(constit, 3640, 4575);
	replace iss_pmdc=1 if inlist(issues_pmdc, 5, 7) & inlist(constit, 1706, 2156);
	replace iss_pmdc=1 if issues_pmdc==1 & inlist(constit, 8617);


	* First those that said unqualified yes to GEB (Gender Equity Bill);
	foreach x in apc slpp pmdc{;
		gen pos_geb_`x'=0 if inrange(geb_`x', 1, 999);
		replace pos_geb_`x'=1 if geb_`x'==1 & inlist(constit, 3640, 2843, 4575, 4800, 8614, 1706, 2156, 2056);
	};
	replace pos_geb_slpp=1 if geb_slpp==1 & inlist(constit, 8553, 7202, 6051, 8617);
	replace pos_geb_pmdc=1 if geb_pmdc==1 & inlist(constit, 6398, 7777, 8617);
	replace pos_geb_apc=1 if geb_apc==1 & inlist(constit, 7777);
	* Below said yes with qualifications;
	replace pos_geb_slpp=1 if geb_slpp==2 & inlist(constit, 6398, 7777);
	replace pos_geb_apc=1 if geb_apc==2 & inlist(constit, 8553, 7202);
	* Below said no;
	replace pos_geb_apc=1 if geb_apc==3 & inlist(constit, 6051, 8617);


	* FHC measure collapses into 3 categories;
	foreach x in apc slpp pmdc{;
		gen pos_fhc_`x'=0 if inrange(fhc_`x', 1, 999);
		replace pos_fhc_`x'=. if constit==8617; 
		* moderator forgot to ask this question in this debate;
	};
	replace pos_fhc_apc=1 if fhc_apc==1 & inlist(constit, 3640, 2843, 4575, 8614, 6051, 7777, 2156, 2056);
	replace pos_fhc_apc=1 if inlist(fhc_apc, 2, 3) & inlist(constit, 8553, 7202, 4800, 1706);
	
	replace pos_fhc_slpp=1 if fhc_slpp==1 & constit==2056;
	replace pos_fhc_slpp=1 if inlist(fhc_slpp, 2, 3) & inlist(constit, 6398, 7202, 4575, 6051, 7777, 2156);
	replace pos_fhc_slpp=1 if fhc_slpp==4 & inlist(constit, 8553, 3640, 2843, 4800, 8614, 1706);

	replace pos_fhc_pmdc=1 if inlist(fhc_pmdc, 2, 3) & inlist(constit, 3640, 4575, 7777);
	replace pos_fhc_pmdc=1 if fhc_pmdc==4 & inlist(constit, 6398, 2843, 1706, 2156, 2056);



*** H2 and H3. Policy Alignment and Persuasion (subset);
	egen roads=anymatch(issues1 issues2), values(3);
	egen educ=anymatch(issues1 issues2), values(2);
	egen agric=anymatch(issues1 issues2), values(1);
	egen health=anymatch(issues1 issues2), values(4);
	egen youthi=anymatch(issues1 issues2), values(5 7);
	gen match_iss=0 if vote_mp<4 & issues1!=.;
	replace match_iss=1 if vote_mp==2 & roads==1 & inlist(constit, 8553, 4575, 8614, 8617);
	replace match_iss=1 if vote_mp==2 & educ==1 & inlist(constit, 6398, 7202, 1706, 2156);
	replace match_iss=1 if vote_mp==2 & youthi==1 & inlist(constit, 3640, 2843);
	replace match_iss=1 if vote_mp==2 & agric==1 & inlist(constit, 4800, 6051, 7777);
	replace match_iss=1 if vote_mp==2 & health==1 & inlist(constit, 2056);
	replace match_iss=1 if vote_mp==1 & roads==1 & inlist(constit, 8553, 3640, 7777, 8617);
	replace match_iss=1 if vote_mp==1 & educ==1 & inlist(constit, 7202, 2843, 4575);
	replace match_iss=1 if vote_mp==1 & health==1 & inlist(constit, 4800, 8614, 1706, 2156, 2056);
	replace match_iss=1 if vote_mp==1 & agric==1 & inlist(constit, 6051);
	replace match_iss=. if vote_mp==1 & constit==6398;
	replace match_iss=1 if vote_mp==3 & educ==1 & inlist(constit, 6398, 2843, 7777, 2056);
	replace match_iss=1 if vote_mp==3 & roads==1 & inlist(constit, 3640, 4575);
	replace match_iss=1 if vote_mp==3 & youthi==1 & inlist(constit, 1706, 2156);
	replace match_iss=1 if vote_mp==3 & agric==1 & inlist(constit, 8617);
	replace match_iss=. if vote_mp==3 & inlist(constit, 8553, 7202, 4800, 8614, 6051);
	
	
	gen match_geb=0 if inrange(geb_law, 1, 999) & vote_mp<4;
	replace match_geb=1 if geb_law==1 & inlist(constit,  3640, 2843, 4575, 4800, 8614, 1706, 2156, 2056) & vote_mp<4;
	replace match_geb=1 if geb_law==1 & vote_mp==3;
	replace match_geb=1 if geb_law==3 & vote_mp==1 & inlist(constit, 6051, 8617);
	replace match_geb=1 if geb_law==1 & vote_mp==2 & inlist(constit, 8617);
	replace match_geb=1 if geb_law==2 & vote_mp==1 & inlist(constit, 8553, 7202);
	replace match_geb=1 if geb_law==1 & vote_mp==2 & inlist(constit, 8553, 7202, 6051);
	replace match_geb=1 if geb_law==2 & vote_mp==2 & inlist(constit, 6398, 7777);
	replace match_geb=1 if geb_law==1 & vote_mp==1 & inlist(constit, 7777);
	replace match_geb=. if vote_mp==1 & constit==6398;
	replace match_geb=. if vote_mp==3 & inlist(constit, 8553, 7202, 4800, 8614, 6051);


	gen match_fhc=0 if fhc_ok<. & vote_mp<4;
	replace match_fhc=1 if fhc_ok==1 & vote_mp==1 & inlist(constit, 3640, 2843, 4575, 8614, 6051, 7777, 2156, 2056);
	replace match_fhc=1 if inlist(fhc_ok, 2, 3) & vote_mp==1 & inlist(constit, 8553, 7202, 4800, 1706);
	replace match_fhc=1 if fhc_ok==1 & vote_mp==2 & inlist(constit, 2056);
	replace match_fhc=1 if inlist(fhc_ok, 2, 3) & vote_mp==2 & inlist(constit, 6398, 7202, 4575, 6051, 7777, 2156);
	replace match_fhc=1 if inlist(fhc_ok, 4) & vote_mp==2 & inlist(constit, 8553, 3640, 2843, 4800, 8614, 1706);
	replace match_fhc=1 if inlist(fhc_ok, 2, 3) & vote_mp==3 & inlist(constit, 3640, 4575, 7777);
	replace match_fhc=1 if inlist(fhc_ok, 4) & vote_mp==3 & inlist(constit, 6398, 2843, 1706, 2156, 2056);
	replace match_fhc=. if constit==8617;
	replace match_fhc=. if vote_mp==1 & constit==6398;
	replace match_fhc=. if vote_mp==3 & inlist(constit, 8553, 7202, 4800, 8614, 6051);



	
*** H4. Voting for the best debate performer;

	*** Merge in debate winners;
	merge m:1 constit using "temp_con_best.dta";
	drop if _m==2;
	drop _merge;
	merge m:1 vrc using "temp_vrc_best.dta";
	drop if _m==2;
	drop _merge;
	gen best=vrcbest;
	replace best=conbest if vrcbest==.;
	merge m:1 constit using "temp_exp_best.dta";
	drop if _m==2;
	drop _merge;
	
	gen vote_expbest=0 if vote_mp<.;
	replace vote_expbest=1 if vote_mp==exp_best;

	gen vote_best=0 if vote_mp<.;
	replace vote_best=1 if vote_mp==best;


*** H5. Crossing party lines;
	gen cpl=0 if vote_mp<.;
	replace cpl=1 if vote_mp==1 & inlist(ethnicity, 2, 8, 6);
	replace cpl=1 if inlist(vote_mp, 2, 3) & inlist(ethnicity, 1, 5, 14, 13, 3, 7);
	replace cpl=1 if vote_mp==4;
	* drop unaffiliated ethnic groups;
	gen unaff=0 if ethnicity<999;
	replace unaff=1 if inlist(ethnicity, 4, 9, 11, 10, 666);
	replace cpl=. if unaff==1; 

	gen diffvote=0 if inlist(vote_mp, 1, 2, 3, 4) & party_2007<.;
	replace diffvote=1 if vote_mp!=party_2007 & vote_mp<. & party_2007<.;

	gen split=0 if inlist(vote_mp, 1, 2, 3, 4) & vote_pres<.;
	replace split=1 if vote_mp!=vote_pres & vote_mp<. & vote_pres<.;


*** H6. Voter Openness;
	gen rank_own=rank_slpp if vote_mp==2;
	replace rank_own=rank_apc if vote_mp==1;
	replace rank_own=rank_pmdc if vote_mp==3;
	gen rank_rival=rank_slpp if vote_mp==1;
	replace rank_rival=rank_apc if vote_mp==2 | vote_mp==3;

	replace rank_pmdc=. if inlist(constit, 8553, 7202, 4800, 8614, 6051);
	replace rank_own=. if vote_mp==3 & inlist(constit, 8553, 7202, 4800, 8614, 6051);
	replace rank_apc=. if constit==6398;
	replace rank_own=. if vote_mp==1 & constit==6398;
	replace rank_rival=. if inlist(vote_mp, 2, 3) & constit==6398;


*** H7. Turnout ;
	gen turnout=vote;
	replace turnout=0 if idcard==2;
	replace turnout=1 if idcard==1;
	replace turnout=. if vote==1 & idcard==3;


*** Code out non-participating candidates;

	* NO PMDC candidate in constituencies 8553, 7202, 4800, 8614, 6051;
	foreach var of varlist name_pmdc iss_pmdc pos_geb_pmdc pos_fhc_pmdc rank_pmdc {;
		replace `var'=. if inlist(constit, 8553, 7202, 4800, 8614, 6051);
	};
	* NO APC candidate in constituency 6398;
	foreach var of varlist name_apc iss_apc pos_geb_apc pos_fhc_apc rank_apc {;
		replace `var'=. if inlist(constit, 6398);
	};


save "`file'", replace;
};

***  Official NEC voting returns data;
use "deb_nec_vrc.dta", clear;
	* Merge in with audience and expert picks;
	merge m:1 constit using "temp_con_best.dta";
	drop _merge;
	merge 1:1 vrc using "temp_vrc_best.dta";
	list vrc if treatment_d==1 & _mer==1;
	drop _merge;
	gen vs_vrcbest=vs_apc if vrcb==1;
	replace vs_vrcbest=vs_slpp if vrcbest==2;
	replace vs_vrcbest=vs_apc if conbest==1 & inrange(status, 2, 5);
	replace vs_vrcbest=vs_slpp if conbest==2 & inrange(status, 2, 5);
	replace vs_vrcbest=vs_apc if conbest==1 & vrc==725781;
	
	merge m:1 constit using "temp_exp_best.dta";
	drop _merge;
	gen vs_expbest=vs_apc if exp_best==1;
	replace vs_expbest=vs_slpp if exp_best==2;
	replace vs_expbest=vs_pmdc if exp_best==3;
	tab strata_debate, gen(vrcbin_);
	tab constit, gen (con_);
save "deb_nec_analysis.dta", replace;


***********************************************;
*** 3. FORMAT CAMPAIGN OUTCOMES  ***;
***********************************************;

use "deb_vrc_analysis.dta", clear;

	foreach x in apc slpp pmdc{;
		gen val_`x'=gift_`x'4;
		replace val_`x'=15 if gift_`x'2==2;
		replace val_`x'=20 if gift_`x'2==3;
		replace val_`x'=5 if gift_`x'2==4;
		replace val_`x'=5 if gift_`x'2==5;
		replace val_`x'=0 if gift_`x'==0;
		gen val_raw_`x'=val_`x';
		replace val_`x'=log(val_`x' +1);
		gen ihs_`x'=ln(val_raw_`x'+((val_raw_`x')^2+1)^0.5);
		replace gift_`x'=100*gift_`x';
		};

	* Code to missing for nonpartipating candidates;
	foreach q in val gift visit ihs val_raw {;
		replace `q'_pmdc=. if inlist(constit, 8553, 7202, 4800, 8614, 6051);
		replace `q'_apc=. if constit==6398;
		};


	* Compile mean by item for Editor;
	egen val_mn=rowmean(val_apc val_slpp val_pmdc);
	egen ihs_mn=rowmean(ihs_apc ihs_slpp ihs_pmdc);
	egen gift_mn=rowmean(gift_apc gift_slpp gift_pmdc);
	egen visit_mn=rowmean(visit_apc visit_slpp visit_pmdc);
	
	* Exploratory: flag where outsider won;
	gen outsider=0;
	replace outsider=1 if constit==3640;
	
		
save "deb_vrc_analysis.dta", replace;

***********************************************;
*** 4. ANALYSIS FOR MAIN TABLES  ***;
***********************************************;


******************;
*** SET MACROS ***;
******************;

local outcomes_h1 "roles cff_close fhc_correct geb_correct name_apc name_slpp name_pmdc iss_apc iss_slpp iss_pmdc pos_geb_apc pos_geb_slpp pos_geb_pmdc pos_fhc_apc pos_fhc_slpp pos_fhc_pmdc";
local outcomes_h2 "match_iss match_geb match_fhc";
local outcomes_h3 "match_geb match_fhc";
local outcomes_h4 "vote_expbest vote_best";
local outcomes_h5 "cpl diffvote split";
local outcomes_h6 "rank_pmdc rank_own rank_rival";
local outcomes_h7 "turnout";

local outcomes_hb "gift_apc gift_slpp gift_pmdc ihs_apc ihs_slpp ihs_pmdc visit_apc visit_slpp visit_pmdc";

local outcomes_hblog "gift_apc gift_slpp gift_pmdc val_apc val_slpp val_pmdc visit_apc visit_slpp visit_pmdc";
local outcomes_hbalt1 "gift_apc gift_slpp gift_pmdc visit_apc visit_slpp visit_pmdc";
local outcomes_hbalt2 "ihs_apc ihs_slpp ihs_pmdc visit_apc visit_slpp visit_pmdc";

local outcomes_hbmnlog "gift_mn val_mn visit_mn";
local outcomes_hbmn "gift_mn ihs_mn visit_mn";

local outcomes_hbapc "gift_apc ihs_apc visit_apc";
local outcomes_hbslpp "gift_slpp ihs_slpp visit_slpp";
local outcomes_hbpmdc "gift_pmdc ihs_pmdc visit_pmdc";

local outcomes_hbapclog "gift_apc val_apc visit_apc";
local outcomes_hbslpplog "gift_slpp val_slpp visit_slpp";
local outcomes_hbpmdclog "gift_pmdc val_pmdc visit_pmdc";

local outcomes_mp "tot_verif visits meetings att_pct all_cmnts tot_comms prior_cmnts prior_cmtee pub_prior";

local controls "yrseduc radio";
local controls_mp "female pub_office";

**************************;
*** TABLE 1: VOTERS ***;
**************************;

*** A. Table 1, Columns 1, 2, 5;

use "deb_vrc_analysis.dta", clear;

forval x = 1 / 7 {;
	local i = `x';
	
* Compile mean effect indices;
	
	foreach var of varlist `outcomes_h`i''{;
		local l = `l' + 1;
		qui sum `var' if t==0;
		qui gen `var'_mean=r(mean);
		qui gen `var'_sd=r(sd);
		qui gen std_`i'_`l'=(`var'-`var'_mean)/`var'_sd;
		qui egen mean_std_`i'_`l'_t=mean(std_`i'_`l') if t==1;
		qui replace std_`i'_`l'=mean_std_`i'_`l'_t if t==1 & std_`i'_`l'==.;
		qui replace std_`i'_`l'=0 if t==0 & std_`i'_`l'==.;
		local zscore_string_`i'="`zscore_string_`i''" + " std_`i'_`l'";
		};
	egen zscore_`i'=rowmean(`zscore_string_`i'');
	local zscore_string_`i'="";
	local l = 0;
	drop *_mean *_sd mean_std* std_*;
	
* Estimate Table 1 Columns 1 (TE and SE) and 2 (naive p one sided);
	reg  zscore_`i' t `controls' bin_* vrcbin_* con_*, cluster(vrc) robust;
	gen te_h`i'=_b[t];
	gen se_h`i'=_se[t];
	gen n_h`i'=e(N);
	test _b[t]=0;
	local sign_h`i'= sign(_b[t]);
	gen p1_h`i' = ttail(r(df_r),`sign_h`i''*sqrt(r(F)));
	gen sig_h`i'="0.90" if p1_h`i'<.10;
	replace sig_h`i'="0.95" if p1_h`i'<.05;
	replace sig_h`i'="0.99" if p1_h`i'<.01;
	gen p2_h`i'=2*(1-normal(abs(te_h`i'/ se_h`i')));
	estimates store z_h`i';
		};
		
save "temp_zscores_pc_ep.dta", replace;

	gen n=_n;
	keep if n==1;
	keep te_* se_* p1_* sig_* n n_h* p2_*;
	reshape long te_ se_ p1_ sig_ n_ p2_, i(n) j(x) string;
	drop n;
	ren x h;
	gen hypo="";
	replace hypo="1 Political Knowledge" if h=="h1";
	replace hypo="2 Policy Alignment" if h=="h2";
	replace hypo="3 Persuasion" if h=="h3";
	replace hypo="4 Vote for Best" if h=="h4";
	replace hypo="5 Cross party lines" if h=="h5";
	replace hypo="6 Openness" if h=="h6";
	replace hypo="7 Turnout" if h=="h7";
	order hypo h te_ se_ p1_ sig_ p2_ ;
	label var te_ "Treatment effect";
	label var se_ "Standard error";
	label var p1_ "Per comparison p, one sided";
	label var p2_ "Per comparions p, two sided";
	label var sig_ "Significance level, one sided";
	drop h;

outsheet using "tab1_cols1_2_5", replace;



*** B. Table 1, Columns 3, 6;

	* Type "browse" to copy and paste p-values from p1_ (p2_) into "fdr_sharpened_qvalues.do" file and run the file to generate Table 1 column 3 (column 6);


*** C. Table 1, Columns 4;

	* Code adapted from Michael Anderson (see http://are.berkeley.edu/~mlanderson);
	* Major DEPARTURES from Anderson: one-sided tests, group level assignment to T/C, cluster at group level;

use "temp_zscores_pc_ep.dta", clear;
keep unique vrc t `controls' bin_* vrcbin_* con_* zscore_*;

* generate variables to store actual and simulated t-stats/p-vals ;

local counter = 1;
gen str20 varname = "";
gen float tstat = .;
gen float act_pval = .;
gen float tstatsim = .;
gen float pvalsim = .;
gen float pvals = .;

* run the original regressions for all of the different outcomes tested and store the actual (observed) p-vals/t-stats;

foreach lhsvar in  zscore_1 zscore_2 zscore_3 zscore_4 zscore_5 zscore_6 zscore_7  {;
    quietly reg `lhsvar' t `controls' bin_* vrcbin_* con_*, cluster(vrc);
    quietly replace tstat = abs(_b[t]/_se[t]) in `counter';

    *quietly replace act_pval = 2*ttail(e(N),abs(tstat)) in `counter';
	
	* ONE SIDED t test ;
	qui test _b[t]=0;
	local sign_`lhsvar'= sign(_b[t]);
	quietly replace act_pval = ttail(r(df_r),`sign_`lhsvar''*sqrt(r(F))) in `counter';
	
	quietly replace varname = "`lhsvar'" in `counter';
    local `lhsvar'_ct_0 = 0;
    local counter = `counter' + 1;
    };

* sort the p-vals by the actual (observed) p-vals (this will reorder some of the obs, but that shouldn't matter);

gsort act_pval;
local endvar = `counter' - 1;

* generate the variable that will contain the simulated (placebo) treatments;

gen byte simtreatment = .;
*gen float simtreatment_uni = .;
local count = 1;

* run [HERE 500 ONLY!] 10,000 iterations of the simulation, record results in p-val storage counters;
while `count' <= 500 {;
* in this section we assign the placebo treatments and run regressions using the placebo treatments;

	*quietly replace simtreatment_uni = uniform();;
	*quietly replace simtreatment = (simtreatment_uni>0.5);		
	
	* ASSIGN placebo T at VRC (cluster) level;
	gen long order = _n;
	egen treat_vrc=tag(vrc);
		
	gen rnd=runiform();
	qui sort treat_vrc rnd;
	qui replace treat_vrc=_n >(_N-112);
	bys vrc (treat_vrc): replace treat_vrc=treat_vrc[_N];
	sort order;
	drop order rnd;
		
	quietly replace simtreatment=treat_vrc;
	drop treat_vrc;

	quietly replace tstatsim = .;
	quietly replace pvalsim = .;
	foreach lhsvar of numlist 1/`endvar' {;
	    local depvar = varname[`lhsvar'];
		quietly reg `depvar' simtreatment `controls' bin_* vrcbin_* con_*, cluster(vrc);
	   	quietly replace tstatsim = abs(_b[simtreatment]/_se[simtreatment]) in `lhsvar';
        
		*quietly replace pvalsim = 2*ttail(e(N),abs(tstatsim)) in `lhsvar';
		
		* ONE SIDED t test;
		qui test _b[simtreatment]=0;
		local sign_`lhsvar'= sign(_b[simtreatment]);
		quietly replace pvalsim = ttail(r(df_r),`sign_`lhsvar''*sqrt(r(F))) in `lhsvar';
		
    	};
* in this section we perform the "step down" procedure that replaces simulated p-vals with the minimum of the set of simulated p-vals associated with outcomes that had actual p-vals greater than or equal to the one being replaced.  For each outcome, we keep count of how many times the ultimate simulated p-val is less than the actual observed p-val.;
    local countdown = `endvar';
    while `countdown' >= 1 {;
        quietly replace pvalsim = min(pvalsim,pvalsim[_n+1]) in `countdown';
        local depvar = varname[`countdown'];
        if pvalsim[`countdown'] <= act_pval[`countdown'] {;
            local `depvar'_ct_0 = ``depvar'_ct_0' + 1;
            };
        local countdown = `countdown' - 1;
    	};
    local count = `count' + 1;
    };

* perform the final adjustment that ensures that the ordering to adjusted p-vals is the same as the original ordering of actual p-vals.  note that this is actually a "step up" procedure rather than a "step down";
foreach lhsvar of numlist 1/`endvar' {;
    local depvar = varname[`lhsvar'];
    quietly replace pvals = max(round(``depvar'_ct_0'/500,.001), pvals[`lhsvar'-1]) in `lhsvar';
    };

list varname pvals if varname!="";


keep varname act_pval pvals;
keep if varname!="";
sort varname;
outsheet using "tab1_col4", replace;

*/;


**********************************;
*** 2. TABLE 2: VOTERS (CONT.) ***;
**********************************;

use "deb_vrc_analysis.dta", clear;

	foreach x in 1 2 4 5 6 7 {;
		foreach var of varlist `outcomes_h`x'' {;
			ttest `var', by(t);
			gen cm_`var'=r(mu_1);
			reg `var' t `controls' bin_* vrcbin_* con_*, cluster(vrc) robust;
			gen te_`var'=_b[t];
			gen se_`var'=_se[t];
			gen N_`var'=e(N);
			test _b[t]=0;
			local sign_`var' = sign(_b[t]);
			gen p_`var' = ttail(r(df_r),`sign_`var''*sqrt(r(F)));
			gen sig_`var'="0.90" if p_`var'<.10;
			replace sig_`var'="0.95" if p_`var'<.05;
			replace sig_`var'="0.99" if p_`var'<.01;
			gen h_`var'=`x';
			};
	};


	gen n=_n;
	keep if n==1;
	keep cm_* N_* te_* se_* p_* sig_* h_* n ;
	reshape long cm_ N_ te_ se_ p_ sig_ h_ , i(n) j(x) string;
	drop n;

	rename x outcome;
	rename cm_ mean_control;
	gen hypo="";
	replace hypo="1 Political Knowledge" if h_==1;
	replace hypo="2 Policy Alignment" if h_==2;
	replace hypo="3 Persuasion" if h_==3;
	replace hypo="4 Vote for Best" if h_==4;
	replace hypo="5 Cross party lines" if h_==5;
	replace hypo="6 Openness" if h_==6;
	replace hypo="7 Turnout" if h_==7;

	sort hypo outcome;
	drop h_;
	order hypo outcome mean_control;
	outsheet using "tab2", replace;

	
	
* Add the 3 outcomes from NEC data; 

use "deb_nec_analysis.dta", clear;
	 * this election was contested and decided later by courts - exclude;
	 drop if constit==8553;
	 * extra "pure" controls have no strata - exclude;
	 drop if strata_debate==.;

	foreach var of varlist vs_expbest vs_vrcbest turnout {;
			ttest `var', by(t);
			gen cm_`var'=r(mu_1);
			reg `var' t vrcbin_* con_*, robust cluster(constit);
			gen te_`var'=_b[t];
			gen se_`var'=_se[t];
			gen N_`var'=e(N);
			test _b[t]=0;
			local sign_`var' = sign(_b[t]);
			gen p_`var' = ttail(r(df_r),`sign_`var''*sqrt(r(F)));
			gen sig_`var'="0.90" if p_`var'<.10;
			replace sig_`var'="0.95" if p_`var'<.05;
			replace sig_`var'="0.99" if p_`var'<.01;
					};
	gen n=_n;
	keep if n==1;
	keep cm_* N_* te_* se_* p_* sig_*  n ;
	reshape long cm_ N_ te_ se_ p_ sig_ , i(n) j(x) string;
	drop n;

	rename x outcome;
	rename cm_ mean_control;
	outsheet using "tab2_nec", replace;	
	
	*** Table 2, column 6 - FDR Qs ;
	* manually run Michael Anderson's FDR adjustment code using output in "$ELEC_out/tab2" by hypothesis;

	
******************************;
*** TABLE 3: CANDIDATES ***;
******************************;

use "deb_vrc_analysis.dta", clear;

* Compile mean effects index;
	local i "b";	
		foreach var of varlist `outcomes_h`i''{;
			local l = `l' + 1;
			qui sum `var' if t==0;
			qui gen `var'_mean=r(mean);
			qui gen `var'_sd=r(sd);
			qui gen std_`i'_`l'=(`var'-`var'_mean)/`var'_sd;
			qui egen mean_std_`i'_`l'_t=mean(std_`i'_`l') if t==1;
			qui replace std_`i'_`l'=mean_std_`i'_`l'_t if t==1 & std_`i'_`l'==.;
			qui replace std_`i'_`l'=0 if t==0 & std_`i'_`l'==.;
			local zscore_string_`i'="`zscore_string_`i''" + " std_`i'_`l'";
			};
		egen zscore_`i'=rowmean(`zscore_string_`i'');
		local zscore_string_`i'="";
		local l = 0;
		drop *_mean *_sd mean_std* std_*;

* Compute treatment effects - two sided tests;
	foreach var of varlist zscore_`i' `outcomes_h`i'' `outcomes_hbmn'{;
			ttest `var', by(t);
			gen cm_`var'=r(mu_1);
		reg `var' t `controls' bin_* vrcbin_* con_*, cluster(vrc) robust;
			gen te_`var'=_b[t];
			gen se_`var'=_se[t];
			gen p_`var'=2*(1-normal(abs(te_`var'/ se_`var')));
			gen sig_`var'="0.90" if p_`var'<.10;
			replace sig_`var'="0.95" if p_`var'<.05;
			replace sig_`var'="0.99" if p_`var'<.01;
			gen N_`var'=e(N);
		};
		
	gen n=_n;
	keep if n==1;
	keep cm_* te_* se_* p_* sig_* n N_*;
	reshape long cm_ te_ se_ p_ sig_ N_, i(n) j(x) string;
	gen panel="B";
	replace panel="A" if x=="zscore_b";
	replace panel="D" if x=="ihs_mn" | x=="gift_mn" | x=="visit_mn";
	sort panel x;
	drop n;
	outsheet using "tab3", replace;
	
	
	*** Table 3 - FDR Qs ;
	* manually run Michael Anderson's FDR adjustment code using the 9 rows of PANEL B output in "$ELEC_out/tab3" by hypothesis;

	
	*** Appendix Table H - Table 3 using log specification of value ***;

use "deb_vrc_analysis.dta", clear;

* Compile mean effects index;
	local i "b";	
		foreach var of varlist `outcomes_h`i'log'{;
			local l = `l' + 1;
			qui sum `var' if t==0;
			qui gen `var'_mean=r(mean);
			qui gen `var'_sd=r(sd);
			qui gen std_`i'_`l'=(`var'-`var'_mean)/`var'_sd;
			qui egen mean_std_`i'_`l'_t=mean(std_`i'_`l') if t==1;
			qui replace std_`i'_`l'=mean_std_`i'_`l'_t if t==1 & std_`i'_`l'==.;
			qui replace std_`i'_`l'=0 if t==0 & std_`i'_`l'==.;
			local zscore_string_`i'="`zscore_string_`i''" + " std_`i'_`l'";
			};
		egen zscore_`i'=rowmean(`zscore_string_`i'');
		local zscore_string_`i'="";
		local l = 0;
		drop *_mean *_sd mean_std* std_*;

* Compute treatment effects - two sided tests;
	foreach var of varlist zscore_`i' `outcomes_h`i'log' `outcomes_hbmnlog'{;
			ttest `var', by(t);
			gen cm_`var'=r(mu_1);
		reg `var' t `controls' bin_* vrcbin_* con_*, cluster(vrc) robust;
			gen te_`var'=_b[t];
			gen se_`var'=_se[t];
			gen p_`var'=2*(1-normal(abs(te_`var'/ se_`var')));
			gen sig_`var'="0.90" if p_`var'<.10;
			replace sig_`var'="0.95" if p_`var'<.05;
			replace sig_`var'="0.99" if p_`var'<.01;
			gen N_`var'=e(N);
		};
		
	gen n=_n;
	keep if n==1;
	keep cm_* te_* se_* p_* sig_* n N_*;
	reshape long cm_ te_ se_ p_ sig_ N_, i(n) j(x) string;
	gen panel="B";
	replace panel="A" if x=="zscore_b";
	replace panel="D" if x=="val_mn" | x=="gift_mn" | x=="visit_mn";
	sort panel x;
	drop n;
	outsheet using "appH", replace;
	
	
	*** Appendix H - FDR Qs ;
	* manually run Michael Anderson's FDR adjustment code using the 9 rows of PANEL B output in "$ELEC_out/tab3" by hypothesis;
	
	
	*** Appendix Table J - heterogeneity by outsider won ***;
use "deb_vrc_analysis.dta", clear;

* Compile mean effects index;
	local i "b";	
		foreach var of varlist `outcomes_h`i''{;
			local l = `l' + 1;
			qui sum `var' if t==0;
			qui gen `var'_mean=r(mean);
			qui gen `var'_sd=r(sd);
			qui gen std_`i'_`l'=(`var'-`var'_mean)/`var'_sd;
			qui egen mean_std_`i'_`l'_t=mean(std_`i'_`l') if t==1;
			qui replace std_`i'_`l'=mean_std_`i'_`l'_t if t==1 & std_`i'_`l'==.;
			qui replace std_`i'_`l'=0 if t==0 & std_`i'_`l'==.;
			local zscore_string_`i'="`zscore_string_`i''" + " std_`i'_`l'";
			};
		egen zscore_`i'=rowmean(`zscore_string_`i'');
		local zscore_string_`i'="";
		local l = 0;
		drop *_mean *_sd mean_std* std_*;

	gen t_out=outsider*t;
	reg zscore_`i' t t_out `controls' bin_* vrcbin_* con_*, cluster(vrc) robust;
		estimates store appI;
		display _b[t_out]+_b[t];
		display (_b[t_out]+_b[t])/_b[t];
		estout appI using "appJ", cells(b(star fmt(%9.3f)) se(par fmt(%9.3f))) stats(N, fmt( %9.0f %9.2f)) style(fixed) starlevels(* .1 ** .05 *** .01) replace;


	
*** Repeat for Editor's request HB Alt 1;

	use "deb_vrc_analysis.dta", clear;

* Compile mean effects index for ALT that drops one of the gift/value outcomes;
	local i "balt1";	
		foreach var of varlist `outcomes_h`i''{;
			local l = `l' + 1;
			qui sum `var' if t==0;
			qui gen `var'_mean=r(mean);
			qui gen `var'_sd=r(sd);
			qui gen std_`i'_`l'=(`var'-`var'_mean)/`var'_sd;
			qui egen mean_std_`i'_`l'_t=mean(std_`i'_`l') if t==1;
			qui replace std_`i'_`l'=mean_std_`i'_`l'_t if t==1 & std_`i'_`l'==.;
			qui replace std_`i'_`l'=0 if t==0 & std_`i'_`l'==.;
			local zscore_string_`i'="`zscore_string_`i''" + " std_`i'_`l'";
			};
		egen zscore_`i'=rowmean(`zscore_string_`i'');
		local zscore_string_`i'="";
		local l = 0;
		drop *_mean *_sd mean_std* std_*;

* Compute treatment effects - two sided tests;
	foreach var of varlist zscore_`i' `outcomes_h`i'' {;
			ttest `var', by(t);
			gen cm_`var'=r(mu_1);
		reg `var' t `controls' bin_* vrcbin_* con_*, cluster(vrc) robust;
			gen te_`var'=_b[t];
			gen se_`var'=_se[t];
			gen p_`var'=2*(1-normal(abs(te_`var'/ se_`var')));
			gen sig_`var'="0.90" if p_`var'<.10;
			replace sig_`var'="0.95" if p_`var'<.05;
			replace sig_`var'="0.99" if p_`var'<.01;
			gen N_`var'=e(N);
		};
		
	gen n=_n;
	keep if n==1;
	keep cm_* te_* se_* p_* sig_* n N_*;
	reshape long cm_ te_ se_ p_ sig_ N_, i(n) j(x) string;
	gen panel="B";
	replace panel="A" if x=="zscore_balt1";
	replace panel="C" if x=="ihs_mn" | x=="gift_mn" | x=="visit_mn";
	sort panel x;
	drop n;
	outsheet using "tab3_alt1", replace;
	
*** Repeat for Editor's request HB Alt 2;

	use "deb_vrc_analysis.dta", clear;

* Compile mean effects index for ALT that drops one of the gift/value outcomes;
	local i "balt2";	
		foreach var of varlist `outcomes_h`i''{;
			local l = `l' + 1;
			qui sum `var' if t==0;
			qui gen `var'_mean=r(mean);
			qui gen `var'_sd=r(sd);
			qui gen std_`i'_`l'=(`var'-`var'_mean)/`var'_sd;
			qui egen mean_std_`i'_`l'_t=mean(std_`i'_`l') if t==1;
			qui replace std_`i'_`l'=mean_std_`i'_`l'_t if t==1 & std_`i'_`l'==.;
			qui replace std_`i'_`l'=0 if t==0 & std_`i'_`l'==.;
			local zscore_string_`i'="`zscore_string_`i''" + " std_`i'_`l'";
			};
		egen zscore_`i'=rowmean(`zscore_string_`i'');
		local zscore_string_`i'="";
		local l = 0;
		drop *_mean *_sd mean_std* std_*;

* Compute treatment effects - two sided tests;
	foreach var of varlist zscore_`i' `outcomes_h`i'' {;
			ttest `var', by(t);
			gen cm_`var'=r(mu_1);
		reg `var' t `controls' bin_* vrcbin_* con_*, cluster(vrc) robust;
			gen te_`var'=_b[t];
			gen se_`var'=_se[t];
			gen p_`var'=2*(1-normal(abs(te_`var'/ se_`var')));
			gen sig_`var'="0.90" if p_`var'<.10;
			replace sig_`var'="0.95" if p_`var'<.05;
			replace sig_`var'="0.99" if p_`var'<.01;
			gen N_`var'=e(N);
		};
		
	gen n=_n;
	keep if n==1;
	keep cm_* te_* se_* p_* sig_* n N_*;
	reshape long cm_ te_ se_ p_ sig_ N_, i(n) j(x) string;
	gen panel="B";
	replace panel="A" if x=="zscore_balt2";
	replace panel="C" if x=="ihs_mn" | x=="gift_mn" | x=="visit_mn";
	sort panel x;
	drop n;
	outsheet using "tab3_alt2", replace;
	
*** Repeat for Editor's request Mean BY PARTY - Panel D;

foreach x in apc slpp pmdc{;
	
	use "deb_vrc_analysis.dta", clear;
	keep if visit_`x'!=. | ihs_`x'!=. | gift_`x'!=.;

* Compile mean effects index for ALT that drops one of the gift/value outcomes;
	local i "`x'";	
		foreach var of varlist `outcomes_hb`i''{;
			local l = `l' + 1;
			qui sum `var' if t==0;
			qui gen `var'_mean=r(mean);
			qui gen `var'_sd=r(sd);
			qui gen std_`i'_`l'=(`var'-`var'_mean)/`var'_sd;
			qui egen mean_std_`i'_`l'_t=mean(std_`i'_`l') if t==1;
			qui replace std_`i'_`l'=mean_std_`i'_`l'_t if t==1 & std_`i'_`l'==.;
			qui replace std_`i'_`l'=0 if t==0 & std_`i'_`l'==.;
			local zscore_string_`i'="`zscore_string_`i''" + " std_`i'_`l'";
			};
		egen zscore_`i'=rowmean(`zscore_string_`i'');
		local zscore_string_`i'="";
		local l = 0;
		drop *_mean *_sd mean_std* std_*;

* Compute treatment effects - two sided tests;
	foreach var of varlist zscore_`i' {;
			ttest `var', by(t);
			gen cm_`var'=r(mu_1);
		reg `var' t `controls' bin_* vrcbin_* con_*, cluster(vrc) robust;
			gen te_`var'=_b[t];
			gen se_`var'=_se[t];
			gen p_`var'=2*(1-normal(abs(te_`var'/ se_`var')));
			gen sig_`var'="0.90" if p_`var'<.10;
			replace sig_`var'="0.95" if p_`var'<.05;
			replace sig_`var'="0.99" if p_`var'<.01;
			gen N_`var'=e(N);
		};
		
	gen n=_n;
	keep if n==1;
	keep cm_* te_* se_* p_* sig_* n N_*;
	reshape long cm_ te_ se_ p_ sig_ N_, i(n) j(x) string;
	gen panel="C";
	sort panel x;
	drop n;
	outsheet using "tab3_panC_`x'", replace;
	};
	
*** And again for Appendix H log spec ***;
	
foreach x in apc slpp pmdc{;
	
	use "deb_vrc_analysis.dta", clear;
	keep if visit_`x'!=. | val_`x'!=. | gift_`x'!=.;

* Compile mean effects index for ALT that drops one of the gift/value outcomes;
	local i "`x'";	
		foreach var of varlist `outcomes_hb`i'log'{;
			local l = `l' + 1;
			qui sum `var' if t==0;
			qui gen `var'_mean=r(mean);
			qui gen `var'_sd=r(sd);
			qui gen std_`i'_`l'=(`var'-`var'_mean)/`var'_sd;
			qui egen mean_std_`i'_`l'_t=mean(std_`i'_`l') if t==1;
			qui replace std_`i'_`l'=mean_std_`i'_`l'_t if t==1 & std_`i'_`l'==.;
			qui replace std_`i'_`l'=0 if t==0 & std_`i'_`l'==.;
			local zscore_string_`i'="`zscore_string_`i''" + " std_`i'_`l'";
			};
		egen zscore_`i'=rowmean(`zscore_string_`i'');
		local zscore_string_`i'="";
		local l = 0;
		drop *_mean *_sd mean_std* std_*;

* Compute treatment effects - two sided tests;
	foreach var of varlist zscore_`i' {;
			ttest `var', by(t);
			gen cm_`var'=r(mu_1);
		reg `var' t `controls' bin_* vrcbin_* con_*, cluster(vrc) robust;
			gen te_`var'=_b[t];
			gen se_`var'=_se[t];
			gen p_`var'=2*(1-normal(abs(te_`var'/ se_`var')));
			gen sig_`var'="0.90" if p_`var'<.10;
			replace sig_`var'="0.95" if p_`var'<.05;
			replace sig_`var'="0.99" if p_`var'<.01;
			gen N_`var'=e(N);
		};
		
	gen n=_n;
	keep if n==1;
	keep cm_* te_* se_* p_* sig_* n N_*;
	reshape long cm_ te_ se_ p_ sig_ N_, i(n) j(x) string;
	gen panel="C";
	sort panel x;
	drop n;
	outsheet using "appH_panC_`x'", replace;
	};	
	
*******************************;
*** 4. TABLE 4: WINNING MPS ***;
*******************************;

* Hypothesis level estimates;
use "deb_parl_records.dta", clear;
	merge 1:1 constit using "deb_field_audits.dta";
	drop _merge;
	
	ren treatment t;
		
	* Compile mean effect indices;
	foreach var of varlist `outcomes_mp'{;
		local l = `l' + 1;
		qui sum `var' if t==0;
		qui gen `var'_mean=r(mean);
		qui gen `var'_sd=r(sd);
		qui gen std_`l'=(`var'-`var'_mean)/`var'_sd;
		qui egen mean_std_`l'_t=mean(std_`l') if t==1;
		qui replace std_`l'=mean_std_`l'_t if t==1 & std_`l'==.;
		qui replace std_`l'=0 if t==0 & std_`l'==.;
		local zscore_string="`zscore_string'" + " std_`l'";
		};
	egen zscore_mp=rowmean(`zscore_string');
	local zscore_string="";
	local l = 0;
	drop *_mean *_sd mean_std*;
	
	reg zscore_mp t `controls_mp' strata1 strata2, vce(ols);
		gen te_h`i'=_b[t];
		gen se_h`i'=_se[t];
		test _b[t]=0;
		local sign_h`i'= sign(_b[t]);
		gen p_h`i' = ttail(r(df_r),`sign_h`i''*sqrt(r(F)));
		gen sig_h`i'="0.90" if p_h`i'<.10;
		replace sig_h`i'="0.95" if p_h`i'<.05;
		replace sig_h`i'="0.99" if p_h`i'<.01;
		reg zscore_mp t strata1 strata2, vce(hc2);
		gen hc2_h`i'=_se[t];

	drop std_*;
	gen n=_n;
	keep if n==1;
	keep te_* se_* p_* sig_* n hc2_*;
	reshape long te_ se_ p_ sig_ hc2_, i(n) j(x) string;
	egen max_se=rowmax(se_ hc2_);
	gen flag="";
	replace flag="retrieve hc2 p-val from log file (/2)" if hc2>se;
	drop n;
	ren x h;
	ren p pols;
	order h te_ max p sig_;
	label var te_ "Treatment effect";
	label var se_ "Standard error";
	label var p "Per comparison p, one sided";
	label var sig_ "Significance level";
	drop h;

outsheet using "tab4_mei", replace;


* Estimate treatment effects - Individual outcomes;
use "deb_parl_records.dta", clear;
	merge 1:1 constit using "deb_field_audits.dta";
	drop _merge;
	local outcomes_mp "tot_verif visits meetings att_pct all_cmnts tot_comms prior_cmnts prior_cmtee pub_prior";
	foreach var of varlist `outcomes_mp' {;
		ttest `var', by(treatment);
		gen cm_`var'=r(mu_1);
		reg `var' treatment `controls_mp' strata1 strata2, vce(ols);
		gen te_`var'=_b[treatment];
		gen se_`var'=_se[treatment];
		gen N_`var'=e(N);
		test _b[treatment]=0;
		local sign_`var' = sign(_b[treatment]);
		gen p_`var' = ttail(r(df_r),`sign_`var''*sqrt(r(F)));
		gen sig_`var'="0.90" if p_`var'<.10;
		replace sig_`var'="0.95" if p_`var'<.05;
		replace sig_`var'="0.99" if p_`var'<.01;
		reg `var' treatment `controls_mp'  strata1 strata2, vce(hc2);
		gen hc2_`var'=_se[treatment];
		};
	gen n=_n;
	keep if n==1;
	keep cm_* N_* te_* se_* p_* sig_* n  hc2_* ;
	reshape long cm_ N_ te_ se_ p_ sig_ hc2_, i(n) j(x) string;
	egen max_se=rowmax(se_ hc2_);
	gen flag="";
	replace flag="retrieve hc2 p-val from log file (/2)" if hc2>se;
	drop n;

	rename x outcome;
	rename cm_ mean_control;
	rename p p_ols;
	gen order=.;
	replace order=1 if outcome=="tot_verif";
	replace order=2 if outcome=="visits";
	replace order=3 if outcome=="meetings";
	replace order=4 if outcome=="att_pct";
	replace order=5 if outcome=="all_cmnts";
	replace order=6 if outcome=="tot_comms";
	replace order=7 if outcome=="prior_cmnts";
	replace order=8 if outcome=="prior_cmtee";
	replace order=9 if outcome=="pub_prior";
	sort order ;
	order outcome mean te max p sig N;
	outsheet using "tab4_ios", replace;

	
	
	
	
******************************;
*** TABLE 5: MECHANISMS ***;
******************************;

*** A. Panel A, rows 1 to 3 - Private Viewing Experiments;
use "deb_ind_analysis.dta", clear;

	keep if compliance==1 & attrition==0;

	foreach num in 1 2 4  {;
		local i = `num';
		foreach t in 1 2 3 {;
			local t=`t';
	
	* Compile mean effect indices;
	
			foreach var of varlist `outcomes_h`i''{;
				local l = `l' + 1;
				sum `var' if t`t'==0;
				qui gen `var'_mean_t`t'=r(mean);
				qui gen `var'_sd_t`t'=r(sd);
				qui gen std_`i'_t`t'_`l'=(`var'-`var'_mean_t`t')/`var'_sd_t`t';
				qui egen mean_std_`i'_t`t'_`l'_t=mean(std_`i'_t`t'_`l') if t`t'==1;
				qui replace std_`i'_t`t'_`l'=mean_std_`i'_t`t'_`l'_t if t`t'==1 & std_`i'_t`t'_`l'==.;
				qui replace std_`i'_t`t'_`l'=0 if t`t'==0 & std_`i'_t`t'_`l'==.;
				local zscore_string_`i'_t`t'="`zscore_string_`i'_t`t''" + " std_`i'_t`t'_`l'";
				};
		egen zscore_`i'_t`t'=rowmean(`zscore_string_`i'_t`t'');
		local zscore_string_`i'_t`t'="";
		local l = 0;
		drop *_mean_t* *_sd_t* mean_std* std_*;
		display "ME Index, KLK07: H`i', T`t'";
		reg  zscore_`i'_t`t' t`t' `controls' hhbin_* vrcbin_* con_*, cluster(vrc) robust;
		gen z_h`i'_t`t'=_b[t`t'];
		gen se_h`i'_t`t'=_se[t`t'];
		gen N_h`i'_t`t'=e(N);
		test _b[t`t']=0;
		local sign_h`i'_t`t'= sign(_b[t`t']);
		gen p_h`i'_t`t' = ttail(r(df_r),`sign_h`i'_t`t''*sqrt(r(F)));
		gen sig_h`i'_t`t'="0.90" if p_h`i'_t`t'<.10;
		replace sig_h`i'_t`t'="0.95" if p_h`i'_t`t'<.05;
		replace sig_h`i'_t`t'="0.99" if p_h`i'_t`t'<.01;
		estimates store z_h`i'_t`t';
			};
		};
	

save "temp_zscores_rel_ts.dta",replace;		

	gen n=_n;
	keep if n==1;
	keep z_* se_* p_* sig_* n N_*;
	reshape long z_ se_ p_ sig_ N_, i(n) j(x) string;
	drop n;
	ren x h;
	gen hlength=length(h);
	gen t_arm=substr( h, -2, .);
	gen hypo=substr(h, 2, 2) if hlength==6;
	replace hypo=substr(h, 2, 1) if hlength==5;
	drop hlength h;
	destring hypo, replace;
	
	label define hypo 1 "Political knowledge" 2 "Policy Alignment" 4 "Vote for best" 5 "Cross party lines" 6 "Openness" 7 "Turnout";

	label values hypo hypo;
	sort t_arm hypo;
	order hypo t_arm z_ se_ p_ sig_;
	label var z_ "Treatment effect";
	label var se_ "Standard error";
	label var p_ "Per comparison p, one sided";
	label var sig_ "Significance level";
	gen table="";
	replace table="ATE - Debates vs Controls" if t_arm=="t1";
	replace table="ATE - GTKU vs Controls" if t_arm=="t2";
	replace table="ATE - Radio vs Controls" if t_arm=="t3";

outsheet using "tab5a_rows123", replace;


*** B. Panel A rows 4 and 5 - Test Treatments against each other using KLK07 Zscores ***;
use  "temp_zscores_rel_ts.dta", clear;
	keep zscore_* t1 t2 t3 t4 t5 hhbin_* vrcbin_* con_* vrc  yrseduc radio ;

	foreach i in 1 2 4   {;

		foreach t in 1 2 3 {;
			reg  zscore_`i'_t`t' `controls' t`t' hhbin_* vrcbin_* con_*;
			est store zh`i't`t';
			};
		suest zh`i't1 zh`i't2 zh`i't3, cluster(vrc); 
	
		lincom [zh`i't1_mean]t1 - [zh`i't2_mean]t2;
		gen relt_h`i'_t1v2=r(estimate);
		gen relse_h`i'_t1v2=r(se);
		test [zh`i't1_mean]t1 =[zh`i't2_mean]t2;
		gen relp_h`i'_t1v2=r(p);
		gen sig_h`i'_t1v2="0.90" if relp_h`i'_t1v2<.10;
		replace sig_h`i'_t1v2="0.95" if relp_h`i'_t1v2<.05;
		replace sig_h`i'_t1v2="0.99" if relp_h`i'_t1v2<.01;

		lincom [zh`i't1_mean]t1 - [zh`i't3_mean]t3;
		gen relt_h`i'_t1v3=r(estimate);
		gen relse_h`i'_t1v3=r(se);
		test [zh`i't1_mean]t1 =[zh`i't3_mean]t3;
		gen relp_h`i'_t1v3=r(p);
		gen sig_h`i'_t1v3="0.90" if relp_h`i'_t1v3<.10;
		replace sig_h`i'_t1v3="0.95" if relp_h`i'_t1v3<.05;
		replace sig_h`i'_t1v3="0.99" if relp_h`i'_t1v3<.01;
	
		lincom [zh`i't3_mean]t3 - [zh`i't2_mean]t2;
		gen relt_h`i'_t3v2=r(estimate);
		gen relse_h`i'_t3v2=r(se);
		test [zh`i't3_mean]t3 =[zh`i't2_mean]t2;
		gen relp_h`i'_t3v2=r(p);
		gen sig_h`i'_t3v2="0.90" if relp_h`i'_t3v2<.10;
		replace sig_h`i'_t3v2="0.95" if relp_h`i'_t3v2<.05;
		replace sig_h`i'_t3v2="0.99" if relp_h`i'_t3v2<.01;
		};

	gen n=_n;
	keep if n==1;
	keep relt_* relse_* relp_* sig_* n;
	reshape long relt_ relse_ relp_ sig_, i(n) j(x) string;
	drop n;
	outsheet using "tab5a_rows45", replace;

*** C. Table 5 - Panel B - Private rows;

use "deb_ind_analysis.dta", clear;
	* Compile and run mean effects using only pure controls as reference group;
	drop if inlist(treatment, 2, 3, 4, 6);
	keep if compliance==1 & attrition==0;
		
	foreach num in 1 2 4 {;
		local i = `num';
		foreach t in 1 {;
			local t=`t';
	
	* Compile mean effect indices;
	
			foreach var of varlist `outcomes_h`i''{;
				local l = `l' + 1;
				sum `var' if t`t'==0;
				qui gen `var'_mean_t`t'=r(mean);
				qui gen `var'_sd_t`t'=r(sd);
				qui gen std_`i'_t`t'_`l'=(`var'-`var'_mean_t`t')/`var'_sd_t`t';
				qui egen mean_std_`i'_t`t'_`l'_t=mean(std_`i'_t`t'_`l') if t`t'==1;
				qui replace std_`i'_t`t'_`l'=mean_std_`i'_t`t'_`l'_t if t`t'==1 & std_`i'_t`t'_`l'==.;
				qui replace std_`i'_t`t'_`l'=0 if t`t'==0 & std_`i'_t`t'_`l'==.;
				local zscore_string_`i'_t`t'="`zscore_string_`i'_t`t''" + " std_`i'_t`t'_`l'";
				};
		egen zscore_`i'_t`t'=rowmean(`zscore_string_`i'_t`t'');
		local zscore_string_`i'_t`t'="";
		local l = 0;
		drop *_mean_t* *_sd_t* mean_std* std_*;
		display "ME Index, KLK07: H`i', T`t'";
		reg  zscore_`i'_t`t' t`t' `controls' hhbin_* vrcbin_* con_*, cluster(vrc) robust;
		gen z_h`i'_t`t'=_b[t`t'];
		gen se_h`i'_t`t'=_se[t`t'];
		gen N_h`i'_t`t'=e(N);
		test _b[t`t']=0;
		local sign_h`i'_t`t'= sign(_b[t`t']);
		gen p_h`i'_t`t' = ttail(r(df_r),`sign_h`i'_t`t''*sqrt(r(F)));
		gen sig_h`i'_t`t'="0.90" if p_h`i'_t`t'<.10;
		replace sig_h`i'_t`t'="0.95" if p_h`i'_t`t'<.05;
		replace sig_h`i'_t`t'="0.99" if p_h`i'_t`t'<.01;
		estimates store z_h`i'_t`t';
			};
	};
	gen dataset="private";
	save "temp_tab5Bpriv.dta", replace;
	gen n=_n;
	keep z_* se_* p_* sig_* n N_*;
	keep if n==1;
	
	reshape long z_ se_ p_ sig_ N_, i(n) j(x) string;
	drop n;
	ren x h;
	gen hlength=length(h);
	gen t_arm=substr( h, -2, .);
	gen hypo=substr(h, 2, 2) if hlength==6;
	replace hypo=substr(h, 2, 1) if hlength==5;
	drop hlength h;
	destring hypo, replace;
	
	label define hypo 1 "Political knowledge" 2 "Policy Alignment" 4 "Vote for best";

	label values hypo hypo;
	sort t_arm hypo;
	order hypo t_arm z_ se_ p_ sig_;
	label var z_ "Treatment effect";
	label var se_ "Standard error";
	label var p_ "Per comparison p, one sided";
	label var sig_ "Significance level";
	gen table="";
	replace table="I-level D vs Pure C" if t_arm=="t1";
	
outsheet using "tab5b_priv", replace;


*** D. Table 5 Panel B - Public ***;
use "deb_vrc_analysis.dta", clear;

	* Select overlapping constituencies only; 
	keep if inlist(constit, 8553, 7202, 4575, 4800, 8614, 1706, 2156, 8617);

	foreach x in 1 2  4  {;
		local i = `x';
	
	* Recompile mean effect indices for this subsample;
	
		foreach var of varlist `outcomes_h`i''{;
			local l = `l' + 1;
			qui sum `var' if t==0;
			qui gen `var'_mean=r(mean);
			qui gen `var'_sd=r(sd);
			qui gen std_`i'_`l'=(`var'-`var'_mean)/`var'_sd;
			qui egen mean_std_`i'_`l'_t=mean(std_`i'_`l') if t==1;
			qui replace std_`i'_`l'=mean_std_`i'_`l'_t if t==1 & std_`i'_`l'==.;
			qui replace std_`i'_`l'=0 if t==0 & std_`i'_`l'==.;
			local zscore_string_`i'="`zscore_string_`i''" + " std_`i'_`l'";
			};
		egen zscore_`i'=rowmean(`zscore_string_`i'');
		local zscore_string_`i'="";
		local l = 0;
		drop *_mean *_sd mean_std* std_*;
	
		reg  zscore_`i' t `controls' bin_* vrcbin_* con_*, cluster(vrc) robust;
			gen te_h`i'=_b[t];
			gen se_h`i'=_se[t];
			gen N_h`i'=e(N);
			test _b[t]=0;
			local sign_h`i'= sign(_b[t]);
			gen p_h`i' = ttail(r(df_r),`sign_h`i''*sqrt(r(F)));
			gen sig_h`i'="0.90" if p_h`i'<.10;
			replace sig_h`i'="0.95" if p_h`i'<.05;
			replace sig_h`i'="0.99" if p_h`i'<.01;
	
		ivregress 2sls zscore_`i' `controls' bin_* vrcbin_* con_*  (exposure=t), cluster(vrc) robust;
			gen ivte_h`i'=_b[exposure];
			gen ivse_h`i'=_se[exposure];
			};
	gen dataset="public";
	save "temp_tab5Bpub.dta", replace;
	gen n=_n;
	keep if n==1;
	keep te_* se_* p_* sig_* n N_* ivte_* ivse_*  ;
	reshape long te_ se_ p_ sig_ N_ ivte_ ivse_ , i(n) j(x) string;
	gen wald= te_/(0.8534-.0274);
	drop n;
	ren x h;
	gen hypo="";
	replace hypo="1 Political Knowledge" if h=="h1";
	replace hypo="2 Policy Alignment" if h=="h2";
	replace hypo="4 Vote for Best" if h=="h4";
	order hypo h te_ se_ wald ivte_ ivse_ p_ sig_;
	label var te_ "Treatment effect";
	label var se_ "Standard error";
	label var p_ "Per comparison p, one sided";
	label var sig_ "Significance level";
	label var wald "Wald scaling = .8534 T compliance and .0274 C noncompliance in subsample";
	label var ivte_ "ATE on compliers";
	label var ivse_ "SE for ATE on compliers";

outsheet using "tab5b_public", replace;

*** Estimate difference in private vs public estimates;
	use "temp_tab5Bpriv.dta", clear;
	append using "temp_tab5Bpub.dta";
	tab dataset;
foreach x in 1 2 4{;
	reg  zscore_`x' t yrseduc radio bin_* vrcbin_* con_* if dataset=="public";
		estimates store e5Bpub;
	reg  zscore_`x'_t1 t1 yrseduc radio hhbin_* vrcbin_* con_1 con_2 con_3 con_4 con_5 con_6 con_7 con_8 if dataset=="private";
		estimates store e5Bpriv;
	suest e5Bpub e5Bpriv, cluster(vrc); 
	test [e5Bpub_mean]t=[e5Bpriv_mean]t1; 
	};
	


***************************************;
***   APPENDIX MATERIAL  ***;
***************************************;

*** Appendix A - NEC vote margins;
*** App A OMITTED because it uniquely identifies constituencies and MPs;



*** Appendix C, Panel A - Balance Lottery 2;
use "deb_vrc_analysis.dta", clear;
	gen replaced=0 if target<.;
	replace replaced=1 if inlist(target, 2, 3);

	foreach var of varlist age female unaff eloyal_apc polyg yrseduc farmer radio nokrio apc_2007 replaced {;
		ttest `var', by(t);
		gen mt_`var'=r(mu_2);
		gen mc_`var'=r(mu_1);
		gen N_`var'=r(N_2) + r(N_1);
		reg `var' t, robust cluster(vrc);
		gen te_`var'=_b[t];
		gen se_`var'=_se[t];
		gen p_`var'=2*(1-normal(abs(te_`var'/ se_`var')));
		reg `var' t bin_* vrcbin_* con_*, robust cluster(vrc);
		gen tes_`var'=_b[t];
		gen ses_`var'=_se[t];
		gen ps_`var'=2*(1-normal(abs(tes_`var'/ ses_`var')));
		};

	gen n=_n;
	keep if n==1;
	keep n mt_* mc_* te_* se_* p_* tes_* ses_* ps_* N_*;
	reshape long mt_ mc_ te_ se_ p_ tes_ ses_ ps_ N_, i(n) j(x) string;	
	gen demog=2;
	replace demog=1 if x=="age" |  x=="female" |  x=="polyg" |  x=="yrseduc" |  x=="farmer" |  x=="radio" |  x=="nokrio";
	replace demog=3 if x=="replaced";
	label def demog 1 "demographics" 2 "politics" 3 "survey";
	label value demog demog;
	sort demog x;
	order x mc mt te_ se_ p_ tes ses ps n;
	drop n;
	gen table="voters (pc-level experiment)";
outsheet using "appC_panA", replace;

*** App C, Panels B - D OMITTED because they identify constituencies and MPs;



*** Appendix D - Balance Lottery 3;
use "deb_ind_analysis.dta", clear;
	gen attrited=0 if attrition<.;
	replace attrited=1 if inrange(attrition, 1, 5);

	tab treatment, gen (tr_);
	forval x=1/6{;
		local i=`x';
		egen N`i'=total(tr_`i');
		foreach var of varlist age female unaff eloyal_apc polyg yrseduc farmer radio nokrio apc_2007 attrited {;
			ttest `var'=0 if treatment==`i';
			gen mn`i'_`var'=r(mu_1);
			gen se`i'_`var'=r(se);
			};
		};

	gen n=_n;
	keep if n==1;
	keep n mn* se* N*;
	reshape long mn1_ mn2_ mn3_ mn4_ mn5_ mn6_ se1_ se2_ se3_ se4_ se5_ se6_ , i(n) j(x) string;	
	drop n;
	gen demog=2;
	replace demog=1 if x=="age" |  x=="female" |  x=="polyg" |  x=="yrseduc" |  x=="farmer" |  x=="radio" |  x=="nokrio";
	replace demog=3 if x=="attrited";
	label def demog 1 "demographics" 2 "politics" 3 "survey";
	label value demog demog;
	sort demog x;
	gen table="voters (i-level arms)";
outsheet using "appD", replace;


*** Appendix G - Treatment Effect Heterogeneity by Subgroups;
use "temp_zscores_pc_ep.dta", clear;

	forval x = 1/7{;
		reg zscore_`x' female_t youth_t nokrio_t t female youth nokrio yrseduc radio bin_* vrcbin_* con_*, cluster(vrc) robust;
		estimates store appg_h`x';
		};

estout appg_* using "appG", cells(b(star fmt(%9.3f)) se(par fmt(%9.3f))) stats(N, fmt( %9.0f %9.2f)) style(fixed) starlevels(* .1 ** .05 *** .01) replace;


*** Appendix H - Table 3 alternative specification IS LOCATED ABOVE UNDER TABLE 3;


*** Appendix I - Other party officials;
local outcomes_c1 "q17 q18 q19 q20 q21 q22 q23 q24 q25 q26 q27 q28 q29 q30 q31 q32 q33 q34 q39 q40 q41";

* Analysis of TE at comm level, excluding I-level VRCs;
use "deb_comm_exit.dta", clear;
	tab const, gen(con_);
	keep if t<.;
	
	* Compile mean effect indices;
	local i = "`c'";
		foreach var of varlist `outcomes_c1'{;
			local l = `l' + 1;
			qui sum `var' if t==0;
			qui gen `var'_mean=r(mean);
			qui gen `var'_sd=r(sd);
			qui gen std_`i'_`l'=(`var'-`var'_mean)/`var'_sd;
			qui egen mean_std_`i'_`l'_t=mean(std_`i'_`l') if t==1;
			qui replace std_`i'_`l'=mean_std_`i'_`l'_t if t==1 & std_`i'_`l'==.;
			qui replace std_`i'_`l'=0 if t==0 & std_`i'_`l'==.;
			local zscore_string_`i'="`zscore_string_`i''" + " std_`i'_`l'";
		};
	egen zscore_`i'=rowmean(`zscore_string_`i'');
	local zscore_string_`i'="";
	local l = 0;
	drop *_mean *_sd mean_std* std_*;
	
	reg  zscore_`i' t vrcbin_* con_*, cluster(vrc) robust;
	gen te_h`i'=_b[t];
	gen se_h`i'=_se[t];
	gen N_h`i'=e(N);
	test _b[t]=0;
	gen p_h`i'=2*(1-normal(abs(te_`x'/ se_`x')));
	gen sig_h`i'="0.90" if p_h`i'<.10;
	replace sig_h`i'="0.95" if p_h`i'<.05;
	replace sig_h`i'="0.99" if p_h`i'<.01;
	estimates store z_h`i';

	gen n=_n;
	keep if n==1;
	keep te_* se_* p_* sig_* n N_*;
	reshape long te_ se_ p_ sig_ N_, i(n) j(x) string;
	drop n;
	ren x h;
	gen hypo="C1 Party Campaigning";
	order hypo h te_ se_ p_ sig_;
	label var te_ "Treatment effect";
	label var se_ "Standard error";
	label var p_ "Per comparison p, two sided";
	label var sig_ "Significance level";
	drop h;

outsheet using "appI_mei", replace;	

* Individual outcomes ;
use "deb_comm_exit.dta", clear;
	tab const, gen(con_);
	keep if t<.;

	foreach x in `outcomes_c1' {;
		sum `x' if t==0;
		gen cmn_`x'=r(mean);
		sum `x';
		gen N_`x'=r(N);
		reg `x' t vrcbin_* con_*, robust cluster(constit);
		gen te_`x'=_b[t];
		gen se_`x'=_se[t];
		gen p_`x'=2*(1-normal(abs(te_`x'/ se_`x')));
		gen sig_`x'="0.90" if p_`x'<.10;
		replace sig_`x'="0.95" if p_`x'<.05;
		replace sig_`x'="0.99" if p_`x'<.01;
	};

	gen n=_n;
	keep if n==1;
	keep cmn_* N_* te_* se_* p_* sig_* n;
	reshape long cmn_ N_ te_ se_ p_ sig_ , i(n) j(x) string;
	drop n;
	foreach x in 17 18 19 20 21 22 23 24 25 26 27 28 29 30 31 32 33 34 39 40 41 37 38{;
		replace x="`x'" if x=="q`x'";
		};
	destring x, replace;
	gen party="APC";
	replace party="PMDC" if inrange(x, 23, 28) | x==40;
	replace party="SLPP" if inrange(x, 29, 34) | x==39;
	replace party="secondary outcomes" if inrange(x, 37, 38);
	sort party x;
	gen item="";
	replace item="any visits" if inlist(x, 17, 23, 29);
	replace item="number of visits" if inlist(x, 18, 24, 30);
	replace item="any rally" if inlist(x, 19, 25, 31);
	replace item="number of rallies" if inlist(x, 20, 26, 32);
	replace item="any gifts" if inlist(x, 21, 27, 33);
	replace item="number people who received gift" if inlist(x, 22, 28, 34);
	replace item="enumerator poster count" if inlist(x, 41, 40, 39);
outsheet using "appI_ios", replace;


*** Appendix J - Heterogeneoue campaign response where trailing won IS LOCATED ABOVE UNDER TABLE 3;


*** Appendix K - Heterogeneous spending response by debate performance;

* calculate continuous measure of audience assessment of who won;
use "deb_vrc_implem.dta", clear;
	keep if after==1;
	gen vshr_apc=0 if cand_best<.;
	replace vshr_apc=1 if cand_best==1;
	gen vshr_slpp=0 if cand_best<.;
	replace vshr_slpp=1 if cand_best==2;
	gen vshr_pmdc=0 if cand_best<.;
	replace vshr_pmdc=1 if cand_best==3;
	* code out non participating candidates;
	replace vshr_pmdc=. if inlist(constit, 8553, 7202, 4800, 8614, 6051);
	replace vshr_apc=. if constit==6398;
	collapse vshr_apc vshr_slpp vshr_pmdc, by(constit);
save "temp_aud_vshrs.dta", replace;

use "deb_vrc_analysis.dta", clear;
	merge m:1 constit using "temp_aud_vshrs.dta";
	keep uniqueid vshr_* constit  t vrc best exp_best bin_* vrcbin_* con_* gift_apc gift_slpp gift_pmdc val_apc val_slpp val_pmdc ihs_apc ihs_slpp ihs_pmdc visit_apc visit_slpp visit_pmdc;
	reshape long gift_ val_ ihs_ visit_ vshr_ , i(uniqueid) j(x) string;

* calculate mean effect indices of 3 campaign items by party;
	foreach var of varlist gift_ ihs_ visit_{;
		foreach p in apc slpp pmdc{;
			qui sum `var' if t==0 & x=="`p'";
			qui gen `var'`p'_mean_`p'=r(mean);
			qui gen `var'`p'_sd=r(sd);
			qui gen std_`var'`p'=(`var'-`var'`p'_mean)/`var'`p'_sd if x=="`p'";
			};
		};
	egen z_slpp=rowmean(std_gift_slpp std_ihs_slpp std_visit_slpp) if x=="slpp";
	egen z_apc=rowmean(std_gift_apc std_ihs_apc std_visit_apc) if x=="apc";
	egen z_pmdc=rowmean(std_gift_pmdc std_ihs_pmdc std_visit_pmdc) if x=="pmdc";
	gen z_generic=z_slpp if x=="slpp";
	replace z_generic=z_apc if x=="apc";
	replace z_generic=z_pmdc if x=="pmdc";

save "temp_aud_vshrs.dta", replace;


* Plot candidate-level TE estimates;
use "temp_aud_vshrs.dta", clear;
	drop if x=="pmdc";
	drop if z_gen==.;
	local k=27;
	tab vshr_, gen(vs_);
	gen bhat=.;
	gen se=.;
	forval i=1/`k'{;
		reg z_generic t  bin_* vrcbin_* con_* if vs_`i'==1, cluster(vrc) robust;
		replace bhat=_b[t] if vs_`i'==1;
		replace se=_se[t] if vs_`i'==1;
		};
	collapse bhat se, by(vshr_);
	twoway (scatter bhat vshr_, sort msymbol(circle_hollow));
	ren bhat cbhat;
save "temp_cand_bhats.dta", replace;

* Plot TEs for 3 bins;

use "temp_aud_vshrs.dta", clear;
	drop if x=="pmdc";
	drop if z_gen==.;
	local k=3;
	xtile vxtile = vshr_, nq(`k');
	replace vxtile=3 if vshr_>.8;
	tab vxtile, gen(vxt_);
	gen bhat=.;
	gen se=.;
	forval i=1/`k'{;
		gen t_vxt_`i'=t*vxt_`i';
		reg z_generic t  bin_* vrcbin_* con_* if vxt_`i'==1, cluster(vrc) robust;
		replace bhat=_b[t] if vxt_`i'==1;
		replace se=_se[t] if vxt_`i'==1;
		};
	reg z_generic t  t_vxt_2 t_vxt_3 vxt_2 vxt_3  bin_* vrcbin_* con_*, cluster(vrc) robust;
	gen upper=bhat+1.96*se;
	gen lower=bhat-1.96*se;
	collapse bhat vshr se upper lower, by(vxtile);
	append using "temp_cand_bhats.dta";
	twoway  (scatter bhat vshr_, sort msize(vlarge) msymbol(square) mcolor(navy)) (rcap upper lower vshr_, msize(vlarge) mcolor(maroon)) (scatter cbhat vshr_, sort msymbol(circle_hollow) mcolor(navy)), xtitle("Bins of audience vote share") ytitle("Campaign expenditure (MEI in std dev units)") legend(lab(1 "Treatment effect by bin") lab(2 "95% confidence interval") lab(3 "Treatment effect by vote share"));
	

graph save "appK_a", replace;

*** Panel B - Minor Party;

* Plot candidate-level TE estimates;
use "temp_aud_vshrs.dta", clear;
	keep if x=="pmdc";
	drop if z_gen==.;
	* 3 got zero votes, so break them up for cand estimates;
	replace vshr_=0.0000000000001 if constit==2056;
	replace vshr_=0.0000000000002 if constit==6398;
	local k=9;
	tab vshr_, gen(vs_);
	gen bhat=.;
	gen se=.;
	forval i=1/`k'{;
		reg z_generic t  bin_* vrcbin_* con_* if vs_`i'==1, cluster(vrc) robust;
		replace bhat=_b[t] if vs_`i'==1;
		replace se=_se[t] if vs_`i'==1;
		};
	collapse bhat se, by(vshr_);
	twoway (scatter bhat vshr_, sort msymbol(circle_hollow));
	ren bhat cbhat;
save "temp_candp_bhats.dta", replace;

* Plot TEs for 4 bins;

use "temp_aud_vshrs.dta", clear;
	keep if x=="pmdc";
	drop if z_gen==.;
	local k=4;
	xtile vxtile = vshr_, nq(`k');
	tab vxtile, gen(vxt_);
	gen bhat=.;
	gen se=.;
	forval i=1/`k'{;
		gen t_vxt_`i'=t*vxt_`i';
		reg z_generic t  bin_* vrcbin_* con_* if vxt_`i'==1, cluster(vrc) robust;
		replace bhat=_b[t] if vxt_`i'==1;
		replace se=_se[t] if vxt_`i'==1;
		};
	reg z_generic t  t_vxt_2 t_vxt_3 t_vxt_4 vxt_2 vxt_3 vxt_4 bin_* vrcbin_* con_*, cluster(vrc) robust;
	gen upper=bhat+1.96*se;
	gen lower=bhat-1.96*se;
	collapse bhat vshr se upper lower, by(vxtile);
	append using "temp_candp_bhats.dta";
	twoway  (scatter bhat vshr_, sort msize(vlarge) msymbol(square) mcolor(navy)) (rcap upper lower vshr_, msize(vlarge) mcolor(maroon)) (scatter cbhat vshr_, sort msymbol(circle_hollow) mcolor(navy)), xtitle("Bins of audience vote share") ytitle("Campaign expenditure (MEI in std dev units)") legend(lab(1 "Treatment effect by bin") lab(2 "95% confidence interval") lab(3 "Treatment effect by vote share"));
	

graph save "appK_b", replace;



*** Appendix L - Distribution of verified CFF by treatment;

use "deb_field_audits.dta", clear;
	histogram tot_verif, bin(10) frequency by(treatment);
graph save "appL", replace;



*** H. Appendix M - Robustness on MP Performance;

* Hypothesis level estimates;
use "deb_parl_records.dta", clear;
	merge 1:1 constit using "deb_field_audits.dta";
	drop _merge;
	
	ren treatment t;
		
	* Compile mean effect indices;
	foreach var of varlist `outcomes_mp'{;
		local l = `l' + 1;
		qui sum `var' if t==0;
		qui gen `var'_mean=r(mean);
		qui gen `var'_sd=r(sd);
		qui gen std_`l'=(`var'-`var'_mean)/`var'_sd;
		qui egen mean_std_`l'_t=mean(std_`l') if t==1;
		qui replace std_`l'=mean_std_`l'_t if t==1 & std_`l'==.;
		qui replace std_`l'=0 if t==0 & std_`l'==.;
		local zscore_string="`zscore_string'" + " std_`l'";
		};
	egen zscore_mp=rowmean(`zscore_string');
	local zscore_string="";
	local l = 0;
	drop *_mean *_sd mean_std*;
	
	reg zscore_mp t strata1 strata2, vce(ols);
		gen te_h`i'=_b[t];
		gen se_h`i'=_se[t];
		test _b[t]=0;
		gen p_h`i'=2*(1-normal(abs(te_h`i'/ se_h`i')));
		gen sig_h`i'="0.90" if p_h`i'<.10;
		replace sig_h`i'="0.95" if p_h`i'<.05;
		replace sig_h`i'="0.99" if p_h`i'<.01;
		reg zscore_mp t strata1 strata2, vce(hc2);
		gen hc2_h`i'=_se[t];

	drop std_*;
	gen n=_n;
	keep if n==1;
	keep te_* se_* p_* sig_* n hc2_*;
	reshape long te_ se_ p_ sig_ hc2_, i(n) j(x) string;
	egen max_se=rowmax(se_ hc2_);
	gen flag="";
	replace flag="retrieve hc2 p-val from log file" if hc2>se;
	drop n;
	ren x h;
	ren p pols;
	order h te_ max p sig_;
	label var te_ "Treatment effect";
	label var se_ "Standard error";
	label var p "Per comparison p, two sided";
	label var sig_ "Significance level";
	drop h;

outsheet using "appM_mei", replace;


* Individual outcomes;
use "deb_parl_records.dta", clear;
	merge 1:1 constit using "deb_field_audits.dta";
	drop _merge;
	
	foreach var of varlist `outcomes_mp' {;
		ttest `var', by(treatment);
		gen cm_`var'=r(mu_1);
		reg `var' treatment strata1 strata2, vce(ols);
		gen te_`var'=_b[treatment];
		gen se_`var'=_se[treatment];
		gen N_`var'=e(N);
		test _b[treatment]=0;
		gen p_`var'=2*(1-normal(abs(te_`var'/ se_`var')));
		gen sig_`var'="0.90" if p_`var'<.10;
		replace sig_`var'="0.95" if p_`var'<.05;
		replace sig_`var'="0.99" if p_`var'<.01;
		reg `var' treatment strata1 strata2, vce(hc2);
		gen hc2_`var'=_se[treatment];
		};
	gen n=_n;
	keep if n==1;
	keep cm_* N_* te_* se_* p_* sig_* n  hc2_* ;
	reshape long cm_ N_ te_ se_ p_ sig_ hc2_, i(n) j(x) string;
	egen max_se=rowmax(se_ hc2_);
	gen flag="";
	replace flag="retrieve hc2 p-val from log file" if hc2>se;
	drop n;

	rename x outcome;
	rename cm_ mean_control;
	rename p p_ols;
	gen order=.;
	replace order=1 if outcome=="tot_verif";
	replace order=2 if outcome=="visits";
	replace order=3 if outcome=="meetings";
	replace order=4 if outcome=="att_pct";
	replace order=5 if outcome=="all_cmnts";
	replace order=6 if outcome=="tot_comms";
	replace order=7 if outcome=="prior_cmnts";
	replace order=8 if outcome=="prior_cmtee";
	replace order=9 if outcome=="pub_prior";
	sort order ;
	order outcome mean te max p sig N;
	outsheet using "appM_ios", replace;
	
		
	
*** H. Appendix N - Survey priming and reinforcing;

* Priming first;
use "deb_ind_analysis.dta", clear;
	keep if compliance==1 & attrition==0;

	foreach num in 1 2 4 {;
		local i = `num';
		foreach t in 4 5{;
			local t=`t';
	
	* Compile mean effect indices wrt pure controls for both of these guys;
	
			foreach var of varlist `outcomes_h`i''{;
				local l = `l' + 1;
				sum `var' if treatment==5;
				qui gen `var'_mean_t`t'=r(mean);
				qui gen `var'_sd_t`t'=r(sd);
				qui gen std_`i'_t`t'_`l'=(`var'-`var'_mean_t`t')/`var'_sd_t`t';
				qui egen mean_std_`i'_t`t'_`l'_t=mean(std_`i'_t`t'_`l') if t`t'==1;
				qui replace std_`i'_t`t'_`l'=mean_std_`i'_t`t'_`l'_t if t`t'==1 & std_`i'_t`t'_`l'==.;
				qui replace std_`i'_t`t'_`l'=0 if t`t'==0 & std_`i'_t`t'_`l'==.;
				local zscore_string_`i'_t`t'="`zscore_string_`i'_t`t''" + " std_`i'_t`t'_`l'";
				};
		egen zscore_`i'_t`t'=rowmean(`zscore_string_`i'_t`t'');
		local zscore_string_`i'_t`t'="";
		local l = 0;
		drop *_mean_t* *_sd_t* mean_std* std_*;
		display "ME Index, KLK07: H`i', T`t'";
		reg  zscore_`i'_t`t' t`t' `controls' hhbin_* vrcbin_* con_*, cluster(vrc) robust;
		gen z_h`i'_t`t'=_b[t`t'];
		gen se_h`i'_t`t'=_se[t`t'];
		gen N_h`i'_t`t'=e(N);
		test _b[t`t']=0;
		local sign_h`i'_t`t'= sign(_b[t`t']);
		gen p_h`i'_t`t' = ttail(r(df_r),`sign_h`i'_t`t''*sqrt(r(F)));
		gen sig_h`i'_t`t'="0.90" if p_h`i'_t`t'<.10;
		replace sig_h`i'_t`t'="0.95" if p_h`i'_t`t'<.05;
		replace sig_h`i'_t`t'="0.99" if p_h`i'_t`t'<.01;
		estimates store z_h`i'_t`t';
			};
	};
	
	gen n=_n;
	keep if n==1;
	keep z_* se_* p_* sig_* n N_*;
	reshape long z_ se_ p_ sig_ N_, i(n) j(x) string;
	drop n;
	ren x h;
	gen hlength=length(h);
	gen t_arm=substr( h, -2, .);
	gen hypo=substr(h, 2, 2) if hlength==6;
	replace hypo=substr(h, 2, 1) if hlength==5;
	drop hlength h;
	destring hypo, replace;
	
	label define hypo 1 "Political knowledge" 2 "Policy Alignment" 4 "Vote for best";

	label values hypo hypo;
	sort t_arm hypo;
	order hypo t_arm z_ se_ p_ sig_;
	label var z_ "Treatment effect";
	label var se_ "Standard error";
	label var p_ "Per comparison p, one sided";
	label var sig_ "Significance level";
	gen table="";
	replace table="Priming - D vs surveyed controls" if t_arm=="t4";
	replace table="Priming - Surveyed vs pure controls" if t_arm=="t5";	

outsheet using "appN_priming", replace;

* Then reinforcing;

use "deb_vrc_analysis.dta", clear;

	foreach x in 1 2  4  {;
		local i = `x';
	
	* Compile mean effect indices for this subsample;
	
		foreach var of varlist `outcomes_h`i''{;
			local l = `l' + 1;
			qui sum `var' if t==0;
			qui gen `var'_mean=r(mean);
			qui gen `var'_sd=r(sd);
			qui gen std_`i'_`l'=(`var'-`var'_mean)/`var'_sd;
			qui egen mean_std_`i'_`l'_t=mean(std_`i'_`l') if t==1;
			qui replace std_`i'_`l'=mean_std_`i'_`l'_t if t==1 & std_`i'_`l'==.;
			qui replace std_`i'_`l'=0 if t==0 & std_`i'_`l'==.;
			local zscore_string_`i'="`zscore_string_`i''" + " std_`i'_`l'";
			};
		egen zscore_`i'=rowmean(`zscore_string_`i'');
		local zscore_string_`i'="";
		local l = 0;
		drop *_mean *_sd mean_std* std_*;
	
		reg zscore_`i' t prime prime_t `controls' bin_* vrcbin_* con_*, cluster(vrc) robust;
			gen te_`i'=_b[t];
			gen se_`i'=_se[t];
			gen N_`i'=e(N);
			test _b[t]=0;
			local sign_`i' = sign(_b[t]);
			gen p_`i' = ttail(r(df_r),`sign_`i''*sqrt(r(F)));
			gen sig_`i'="0.90" if p_`i'<.10;
			replace sig_`i'="0.95" if p_`i'<.05;
			replace sig_`i'="0.99" if p_`i'<.01;
			
			gen pte_`i'=_b[prime_t];
			gen pse_`i'=_se[prime_t];
			test _b[prime_t]=0;
			local psign_`i' = sign(_b[prime_t]);
			gen pp_`i' = ttail(r(df_r),`psign_`i''*sqrt(r(F)));
			gen psig_`i'="0.90" if pp_`i'<.10;
			replace psig_`i'="0.95" if pp_`i'<.05;
			replace psig_`i'="0.99" if pp_`i'<.01;
			gen h_`i'=`x';
		};


	gen n=_n;
	keep if n==1;
	keep te_* se_* p_* sig_* pte_* pse_* pp_* psig_* h_* n N_*;
	reshape long te_ se_ p_ sig_ pte_ pse_ pp_ psig_ h_ N_, i(n) j(x) string;
	drop n;
	rename x outcome;
	gen hypo="";
	replace hypo="H1. Political Knowledge" if h_==1;
	replace hypo="H2. Policy Alignment" if h_==2;
	replace hypo="H4. Vote for best" if h_==4;
	sort h_ outcome;
	drop h_;
	order hypo outcome ;
	order N, last;
	outsheet using "appN_reinforcing", replace;

	



*** Tidy up;
erase "temp_vrc_best.dta";
erase "temp_exp_best.dta";
erase "temp_con_best.dta";
erase "temp_zscores_pc_ep.dta";
erase "temp_zscores_rel_ts.dta";
erase "deb_vrc_analysis.dta";
erase "deb_ind_analysis.dta";
erase "deb_nec_analysis.dta";
erase "temp_aud_vshrs.dta";
erase "temp_cand_bhats.dta";
erase "temp_candp_bhats.dta";
erase "temp_tab5Bpriv.dta";
erase "temp_tab5Bpub.dta";

